# -*- coding: utf-8 -*-

from __future__ import print_function

from django.conf import settings

from django_rlog.defaults import DEFAULT_CHANNEL
from django_rlog.logger import get_logger
from django_rlog.management.commands._arguments import _add_arguments
from django_six import CompatibilityBaseCommand


r = settings.REDIS_CACHE


class Command(CompatibilityBaseCommand):
    help = "Save rlog's RedisHandler Log to Disk."

    def add_arguments(self, parser):
        parser.add_argument(
            '--channel',
            dest='channel',
            default=DEFAULT_CHANNEL,
            help='Pubsub channel RedisHandler use.',
        )
        _add_arguments(parser)

    def handle(self, *args, **options):
        debug = options.get('debug', False)
        logger = get_logger(**options)
        p = r.pubsub()
        p.subscribe(options.get('channel', DEFAULT_CHANNEL))
        for item in p.listen():
            if debug:
                print(item)
            p.unsubscribe() if item['data'] == 'KILL' else logger.debug(item.get('data', ''))



# -*- coding: utf-8 -*-

from django.conf import settings

from django_rlog.defaults import DEFAULT_CHANNEL
from django_six import CompatibilityBaseCommand


r = settings.REDIS_CACHE


class Command(CompatibilityBaseCommand):
    help = 'Stop rlog.'

    def add_arguments(self, parser):
        parser.add_argument(
            '--channel',
            dest='channel',
            default=DEFAULT_CHANNEL,
            help='Pubsub channel RedisHandler usage.',
        )

    def handle(self, *args, **options):
        r.publish(options.get('channel', DEFAULT_CHANNEL), 'KILL')



# -*- coding: utf-8 -*-

from django_rlog.defaults import (DEFAULT_BACKUP_COUNT, DEFAULT_FILENAME, DEFAULT_HANDLER, DEFAULT_MAX_BYTES,
                                  DEFAULT_WHEN)


def _add_arguments(parser):
    """Add Common Arguments"""
    parser.add_argument(
        '--filename',
        dest='filename',
        default=DEFAULT_FILENAME,
        help='Filename log write into.',
    )
    parser.add_argument(
        '--handler',
        dest='handler',
        default=DEFAULT_HANDLER,
        help='FileHandler to use.',
    )
    parser.add_argument(
        '--when',
        dest='when',
        default=DEFAULT_WHEN,
        help='When of TimedRotatingFileHandler.',
    )
    parser.add_argument(
        '--maxBytes',
        dest='maxBytes',
        default=DEFAULT_MAX_BYTES,
        type=int,
        help='MaxBytes of RotatingFileHandler.',
    )
    parser.add_argument(
        '--backupCount',
        dest='backupCount',
        default=DEFAULT_BACKUP_COUNT,
        type=int,
        help='BackupCount of TimedRotatingFileHandler/RotatingFileHandler.',
    )
    parser.add_argument(
        '--debug',
        action='store_true',
        dest='debug',
        default=False,
        help='Print info or not.',
    )



# -*- coding: utf-8 -*-

import logging
import logging.handlers

from django_rlog.defaults import (DEFAULT_BACKUP_COUNT, DEFAULT_FILENAME, DEFAULT_HANDLER, DEFAULT_MAX_BYTES,
                                  DEFAULT_WHEN)


def get_handler(**options):
    """Support FileHandler/RotatingFileHandler/TimedRotatingFileHandler"""
    filename = options.get('filename', DEFAULT_FILENAME)
    handler = options.get('handler', DEFAULT_HANDLER)
    when = options.get('when', DEFAULT_WHEN)
    maxBytes = options.get('maxBytes', DEFAULT_MAX_BYTES)
    backupCount = options.get('backupCount', DEFAULT_BACKUP_COUNT)

    if handler == 'TimedRotatingFileHandler':
        return logging.handlers.TimedRotatingFileHandler(filename, when=when, backupCount=backupCount)
    elif handler == 'RotatingFileHandler':
        return logging.handlers.RotatingFileHandler(filename, maxBytes=maxBytes, backupCount=backupCount)
    else:
        return logging.FileHandler(filename)


def get_logger(**options):
    logger = logging.getLogger()
    logger.setLevel(logging.DEBUG)
    logger.addHandler(get_handler(**options))
    return logger



# -*- coding: utf-8 -*-

# Default Channel RedisHandler Use
DEFAULT_CHANNEL = 'django-logit'

# Default Key RedisListHandler Use
DEFAULT_KEY = 'django:logit'

# Default Timeout for BLPOP/BRPOP
DEFAULT_TIMEOUT = 60

# Default Filename Logs Write Into
DEFAULT_FILENAME = '/tmp/django-logit.log'

# Default Handler Logger Use
DEFAULT_HANDLER = 'TimedRotatingFileHandler'

# Default When for TimedRotatingFileHandler
DEFAULT_WHEN = 'midnight'

# Default MaxBytes for RotatingFileHandler
DEFAULT_MAX_BYTES = 15728640  # 1024 * 1024 * 15B = 15MB

# Default Backup Count for TimedRotatingFileHandler/RotatingFileHandler
DEFAULT_BACKUP_COUNT = 10



# -*- coding: utf-8 -*-

from __future__ import print_function

from django.conf import settings

from django_rlog.defaults import DEFAULT_KEY, DEFAULT_TIMEOUT
from django_rlog.logger import get_logger
from django_rlog.management.commands._arguments import _add_arguments
from django_six import CompatibilityBaseCommand


r = settings.REDIS_CACHE


class Command(CompatibilityBaseCommand):
    help = "Save rlog's RedisListHandler Log to Disk."

    def add_arguments(self, parser):
        parser.add_argument(
            '--key',
            dest='key',
            default=DEFAULT_KEY,
            help='Key RedisListHandler use.',
        )
        parser.add_argument(
            '--timeout',
            dest='timeout',
            default=DEFAULT_TIMEOUT,
            type=int,
            help='Timeout of BLPOP/BRPOP.',
        )
        _add_arguments(parser)

    def handle(self, *args, **options):
        debug = options.get('debug', False)
        logger = get_logger(**options)
        key = options.get('key', DEFAULT_KEY)
        timeout = options.get('timeout', DEFAULT_TIMEOUT)
        while True:
            data = r.blpop(key, timeout)
            if data:
                if debug:
                    print(data)
                logger.debug(data[-1])
